/// <reference types="node" />
import { IronfishSdk, Logger } from '@ironfish/sdk';
import { Command, Config } from '@oclif/core';
import { ConfigFlagKey, DataDirFlagKey, RpcAuthFlagKey, RpcHttpHostFlagKey, RpcHttpPortFlagKey, RpcTcpHostFlagKey, RpcTcpPortFlagKey, RpcTcpTlsFlagKey, RpcUseHttpFlagKey, RpcUseIpcFlagKey, RpcUseTcpFlagKey, VerboseFlagKey } from './flags';
export type SIGNALS = 'SIGTERM' | 'SIGINT' | 'SIGUSR2';
export type FLAGS = typeof DataDirFlagKey | typeof ConfigFlagKey | typeof RpcUseIpcFlagKey | typeof RpcUseTcpFlagKey | typeof RpcTcpHostFlagKey | typeof RpcTcpPortFlagKey | typeof RpcUseHttpFlagKey | typeof RpcHttpHostFlagKey | typeof RpcHttpPortFlagKey | typeof RpcTcpTlsFlagKey | typeof VerboseFlagKey | typeof RpcAuthFlagKey;
export declare abstract class IronfishCommand extends Command {
    sdk: IronfishSdk;
    /**
     * Use this logger instance for debug/error output.
     * Actual command output should use `this.log` instead.
     */
    logger: Logger;
    /**
     * Set to true when the command is closing so any async things in the command can interrupt and quit
     */
    closing: boolean;
    constructor(argv: string[], config: Config);
    abstract start(): Promise<void> | void;
    run(): Promise<void>;
    init(): Promise<void>;
    listenForSignals(): void;
    closeFromSignal(signal: NodeJS.Signals): Promise<unknown>;
}
//# sourceMappingURL=command.d.ts.map