"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const utils_1 = require("../../utils");
class CeremonyContributions extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(CeremonyContributions);
        const r2Credentials = await utils_1.S3Utils.getR2Credentials();
        if (r2Credentials === undefined) {
            this.logger.log('Failed getting R2 credentials from AWS');
            this.exit(0);
            return;
        }
        const r2Client = utils_1.S3Utils.getR2S3Client(r2Credentials);
        const latestParamName = await this.getLatestParamName(r2Client, 'ironfish-contributions');
        const latestParamNumber = parseInt(latestParamName.split('_')[1]);
        const keys = [...new Array(latestParamNumber + 1)]
            .map((_, i) => i)
            .filter((i) => (!flags.start || i >= flags.start) && (!flags.end || i <= flags.end))
            .map((i) => {
            return 'params_' + i.toString().padStart(5, '0');
        });
        for (const key of keys) {
            const { Metadata } = await utils_1.S3Utils.getObjectMetadata(r2Client, 'ironfish-contributions', key);
            this.log(`Contribution: ${key.split('_')[1]}, Name: ${Metadata?.contributorName || '-'}, IP: ${Metadata?.remoteaddress || '-'}`);
        }
    }
    async getLatestParamName(client, bucket) {
        const paramFileNames = await utils_1.S3Utils.getBucketObjects(client, bucket);
        const validParams = paramFileNames
            .slice(0)
            .filter((fileName) => /^params_\d{5}$/.test(fileName));
        validParams.sort();
        return validParams[validParams.length - 1];
    }
}
CeremonyContributions.description = 'List all the current contributions with names';
CeremonyContributions.flags = {
    start: core_1.Flags.integer({
        required: false,
    }),
    end: core_1.Flags.integer({
        required: false,
    }),
};
exports.default = CeremonyContributions;
//# sourceMappingURL=contributions.js.map