"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class Asset extends command_1.IronfishCommand {
    async start() {
        const { args } = await this.parse(Asset);
        sdk_1.Assert.isString(args.id);
        const assetId = args.id;
        const client = await this.sdk.connectRpc();
        const data = await client.chain.getAsset({ id: assetId });
        this.log(`Name: ${sdk_1.BufferUtils.toHuman(Buffer.from(data.content.name, 'hex'))}`);
        this.log(`Metadata: ${sdk_1.BufferUtils.toHuman(Buffer.from(data.content.metadata, 'hex'))}`);
        this.log(`Creator: ${data.content.creator}`);
        this.log(`Owner: ${data.content.owner}`);
        this.log(`Supply: ${data.content.supply ?? 'N/A'}`);
        this.log(`Identifier: ${data.content.id}`);
        this.log(`Transaction Created: ${data.content.createdTransactionHash}`);
    }
}
Asset.description = 'Get the asset info';
Asset.args = [
    {
        name: 'id',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'The identifier of the asset',
    },
];
Asset.flags = {
    ...flags_1.RemoteFlags,
};
exports.default = Asset;
//# sourceMappingURL=asset.js.map