"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const fs_1 = __importDefault(require("fs"));
const args_1 = require("../../args");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class Export extends command_1.IronfishCommand {
    async start() {
        const { flags, args } = await this.parse(Export);
        const exportDir = flags.path
            ? this.sdk.fileSystem.resolve(flags.path)
            : this.sdk.config.dataDir;
        const exportPath = this.sdk.fileSystem.join(exportDir, 'data.json');
        const client = await this.sdk.connectRpc();
        const stream = client.chain.exportChainStream({
            start: args.start,
            stop: args.stop,
        });
        const { start, stop } = await sdk_1.AsyncUtils.first(stream.contentStream());
        this.log(`Exporting chain from ${start} -> ${stop} to ${exportPath}`);
        const progress = core_1.CliUx.ux.progress({
            format: 'Exporting blocks: [{bar}] {value}/{total} {percentage}% | ETA: {eta}s',
        });
        progress.start(stop - start + 1, 0);
        const results = [];
        for await (const result of stream.contentStream()) {
            results.push(result.block);
            progress.update((result.block?.sequence || 0) - start + 1);
        }
        progress.stop();
        await this.sdk.fileSystem.mkdir(exportDir, { recursive: true });
        await fs_1.default.promises.writeFile(exportPath, JSON.stringify(results, undefined, '  '));
        this.log('Export complete');
    }
}
Export.description = 'Export part of the chain database to JSON';
Export.flags = {
    ...flags_1.RemoteFlags,
    path: core_1.Flags.string({
        char: 'p',
        parse: (input) => Promise.resolve(input.trim()),
        required: false,
        description: 'The path to export the chain to',
    }),
};
Export.args = [
    {
        name: 'start',
        parse: (input) => Promise.resolve((0, args_1.parseNumber)(input)),
        default: Number(sdk_1.GENESIS_BLOCK_SEQUENCE),
        required: false,
        description: 'The sequence to start at (inclusive, genesis block is 1)',
    },
    {
        name: 'stop',
        parse: (input) => Promise.resolve((0, args_1.parseNumber)(input)),
        required: false,
        description: 'The sequence to end at (inclusive)',
    },
];
exports.default = Export;
//# sourceMappingURL=export.js.map