"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const args_1 = require("../../args");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class Power extends command_1.IronfishCommand {
    async start() {
        const { flags, args } = await this.parse(Power);
        const block = args.block;
        const client = await this.sdk.connectRpc();
        const data = await client.chain.getNetworkHashPower({
            sequence: block,
            blocks: flags.history,
        });
        const formattedHashesPerSecond = sdk_1.FileUtils.formatHashRate(data.content.hashesPerSecond);
        this.log(`The network power for block ${data.content.sequence} was ${formattedHashesPerSecond} averaged over ${data.content.blocks} previous blocks.`);
    }
}
Power.description = "Show the network's hash power per second";
Power.flags = {
    ...flags_1.LocalFlags,
    history: core_1.Flags.integer({
        required: false,
        description: 'The number of blocks to look back to calculate the network hashes per second',
    }),
};
Power.args = [
    {
        name: 'block',
        parse: (input) => Promise.resolve((0, args_1.parseNumber)(input)),
        required: false,
        description: 'The sequence of the block to estimate network speed for',
    },
];
exports.default = Power;
//# sourceMappingURL=power.js.map