"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class Prune extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(Prune);
        core_1.CliUx.ux.action.start(`Opening node`);
        const node = await this.sdk.node();
        await node.openDB();
        await node.chain.open();
        core_1.CliUx.ux.action.stop('done.');
        if (flags.prune) {
            const { start, stop } = sdk_1.BlockchainUtils.getBlockRange(node.chain, {
                start: 1,
                stop: node.chain.latest.sequence - 100,
            });
            this.log(`Pruning from ${start} to ${stop}`);
            let total = 0;
            for (let sequence = stop; sequence >= start; --sequence) {
                const hashes = await node.chain.getHashesAtSequence(sequence);
                const main = await node.chain.getHashAtSequence(sequence);
                const forks = hashes.filter((h) => !main || !h.equals(main));
                if (forks.length > 0) {
                    if (!flags.dry) {
                        await Promise.all(forks.map((h) => node.chain.removeBlock(h)));
                    }
                    total += forks.length;
                    this.log(`Pruned ${sequence
                        .toString()
                        .padStart(node.chain.latest.sequence.toString().length)}: ${forks.length} (${total})`);
                }
            }
            this.log(`Pruned a total of ${total} forking blocks from ${stop} to ${start}`);
        }
        if (flags.compact) {
            core_1.CliUx.ux.action.start(`Compacting Database`);
            await node.chain.blockchainDb.compact();
            core_1.CliUx.ux.action.stop();
        }
        await node.chain.close();
        await node.closeDB();
    }
}
Prune.description = 'Remove old blocks from the chain';
Prune.hidden = false;
Prune.flags = {
    ...flags_1.LocalFlags,
    dry: core_1.Flags.boolean({
        default: false,
        description: 'Dry run prune first',
    }),
    prune: core_1.Flags.boolean({
        char: 'p',
        default: true,
        allowNo: true,
        description: 'Delete blocks on forks',
    }),
    compact: core_1.Flags.boolean({
        char: 'c',
        default: true,
        allowNo: true,
        description: 'Compact the database',
    }),
};
exports.default = Prune;
//# sourceMappingURL=prune.js.map