"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class ReAddBlock extends command_1.IronfishCommand {
    async start() {
        const { args } = await this.parse(ReAddBlock);
        const hash = Buffer.from(args.hash, 'hex');
        core_1.CliUx.ux.action.start(`Opening node`);
        const node = await this.sdk.node();
        await node.openDB();
        await node.chain.open();
        core_1.CliUx.ux.action.stop('done.');
        const block = await node.chain.getBlock(hash);
        if (!block) {
            this.log(`No block found with hash ${hash.toString('hex')}`);
            return this.exit(0);
        }
        await node.chain.removeBlock(hash);
        await node.chain.addBlock(block);
        this.log('Block has been reimported.');
    }
}
ReAddBlock.description = 'Remove and readd a block on the chain if it has no other blocks after it';
ReAddBlock.hidden = true;
ReAddBlock.flags = {
    ...flags_1.LocalFlags,
};
ReAddBlock.args = [
    {
        name: 'hash',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'The hash of the block in hex format',
    },
];
exports.default = ReAddBlock;
//# sourceMappingURL=readd-block.js.map