"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const fs_1 = require("fs");
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
const utils_1 = require("../../utils");
const mkdtempAsync = (0, util_1.promisify)(fs_1.mkdtemp);
const writeFileAsync = (0, util_1.promisify)(fs_1.writeFile);
const readFileAsync = (0, util_1.promisify)(fs_1.readFile);
class EditCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(EditCommand);
        if (!flags.remote) {
            const configPath = this.sdk.config.storage.configPath;
            this.log(`Editing ${configPath}`);
            const code = await (0, utils_1.launchEditor)(configPath, this.sdk.config);
            this.exit(code || undefined);
        }
        const client = await this.sdk.connectRpc(!flags.remote);
        const response = await client.config.getConfig({ user: true });
        const output = JSON.stringify(response.content, undefined, '   ');
        const tmpDir = os_1.default.tmpdir();
        const folderPath = await mkdtempAsync(path_1.default.join(tmpDir, '@ironfish-sdk-'));
        const filePath = path_1.default.join(folderPath, sdk_1.DEFAULT_CONFIG_NAME);
        await writeFileAsync(filePath, output);
        const code = await (0, utils_1.launchEditor)(filePath, this.sdk.config);
        if (code !== 0) {
            this.exit(code || undefined);
        }
        const content = await readFileAsync(filePath, { encoding: 'utf8' });
        const config = sdk_1.JSONUtils.parse(content);
        await client.config.uploadConfig({ config });
        this.log('Uploaded config successfully.');
        this.exit(0);
    }
}
EditCommand.description = `Edit the config in your configured editor

  Set the editor in either EDITOR environment variable, or set 'editor' in your ironfish config`;
EditCommand.flags = {
    [flags_1.ConfigFlagKey]: flags_1.ConfigFlag,
    [flags_1.DataDirFlagKey]: flags_1.DataDirFlag,
    remote: core_1.Flags.boolean({
        default: false,
        description: 'Connect to the node when editing the config',
    }),
};
exports.EditCommand = EditCommand;
//# sourceMappingURL=edit.js.map