"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetCommand = void 0;
const core_1 = require("@oclif/core");
const json_colorizer_1 = __importDefault(require("json-colorizer"));
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class GetCommand extends command_1.IronfishCommand {
    async start() {
        const { args, flags } = await this.parse(GetCommand);
        const name = args.name.trim();
        const client = await this.sdk.connectRpc(flags.local);
        const response = await client.config.getConfig({
            user: flags.user,
            name: name,
        });
        const key = name;
        if (response.content[key] === undefined) {
            this.exit(0);
        }
        let output = '';
        if (flags.json) {
            output = JSON.stringify(response.content[key], undefined, '   ');
            if (flags.color) {
                output = (0, json_colorizer_1.default)(output);
            }
        }
        else {
            output = String(response.content[key]);
        }
        this.log(output);
        this.exit(0);
    }
}
GetCommand.description = `Print out one config value`;
GetCommand.args = [
    {
        name: 'name',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'Name of the config item',
    },
];
GetCommand.flags = {
    ...flags_1.RemoteFlags,
    user: core_1.Flags.boolean({
        description: 'Only show config from the users datadir and not overrides',
    }),
    local: core_1.Flags.boolean({
        default: false,
        description: 'Dont connect to the node when displaying the config',
    }),
    color: core_1.Flags.boolean({
        default: true,
        allowNo: true,
        description: 'Should colorize the output',
    }),
    json: core_1.Flags.boolean({
        default: false,
        allowNo: true,
        description: 'Output the config value as json',
    }),
};
exports.GetCommand = GetCommand;
//# sourceMappingURL=get.js.map