"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class SetCommand extends command_1.IronfishCommand {
    async start() {
        const { args, flags } = await this.parse(SetCommand);
        const name = args.name;
        const value = args.value;
        const client = await this.sdk.connectRpc(flags.local);
        await client.config.setConfig({ name, value });
        this.exit(0);
    }
}
SetCommand.description = `Set a value in the config`;
SetCommand.args = [
    {
        name: 'name',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'Name of the config item',
    },
    {
        name: 'value',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'Value of the config item',
    },
];
SetCommand.flags = {
    ...flags_1.RemoteFlags,
    local: core_1.Flags.boolean({
        default: false,
        description: 'Dont connect to the node when updating the config',
    }),
};
SetCommand.examples = [
    '$ ironfish config:set bootstrapNodes "test.bn1.ironfish.network,example.com"',
];
exports.SetCommand = SetCommand;
//# sourceMappingURL=set.js.map