"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnsetCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class UnsetCommand extends command_1.IronfishCommand {
    async start() {
        const { args, flags } = await this.parse(UnsetCommand);
        const name = args.name;
        const client = await this.sdk.connectRpc(flags.local);
        await client.config.unsetConfig({ name });
        this.exit(0);
    }
}
UnsetCommand.description = `Unset a value in the config and fall back to default`;
UnsetCommand.args = [
    {
        name: 'name',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'Name of the config item',
    },
];
UnsetCommand.flags = {
    ...flags_1.RemoteFlags,
    local: core_1.Flags.boolean({
        default: false,
        description: 'Dont connect to the node when updating the config',
    }),
};
UnsetCommand.examples = ['$ ironfish config:unset blockGraffiti'];
exports.UnsetCommand = UnsetCommand;
//# sourceMappingURL=unset.js.map