"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FaucetCommand = void 0;
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../command");
const flags_1 = require("../flags");
const images_1 = require("../images");
const FAUCET_DISABLED = false;
class FaucetCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(FaucetCommand);
        if (FAUCET_DISABLED && !flags.force) {
            this.log(`❌ The faucet is currently disabled. Check ${sdk_1.DEFAULT_DISCORD_INVITE} ❌`);
            this.exit(1);
        }
        const client = await this.sdk.connectRpc();
        const networkInfoResponse = await client.chain.getNetworkInfo();
        if (networkInfoResponse.content === null || networkInfoResponse.content.networkId !== 0) {
            // not testnet
            this.log(`The faucet is only available for testnet.`);
            this.exit(1);
        }
        this.log(images_1.ONE_FISH_IMAGE);
        let email = flags.email;
        if (!email) {
            email =
                (await core_1.CliUx.ux.prompt('Enter your email to stay updated with Iron Fish', {
                    required: false,
                })) || undefined;
        }
        // Create an account if one is not set
        const response = await client.wallet.getDefaultAccount();
        let accountName = response.content.account?.name;
        if (!accountName) {
            this.log(`You don't have a default account set up yet. Let's create one first!`);
            accountName =
                (await core_1.CliUx.ux.prompt('Please enter the name of your new Iron Fish account', {
                    required: false,
                })) || 'default';
            await client.wallet.createAccount({ name: accountName, default: true });
        }
        core_1.CliUx.ux.action.start('Collecting your funds', 'Sending a request to the Iron Fish network', {
            stdout: true,
        });
        try {
            await client.faucet.getFunds({
                account: accountName,
                email,
            });
        }
        catch (error) {
            if (error instanceof sdk_1.RpcRequestError) {
                core_1.CliUx.ux.action.stop(error.codeMessage);
            }
            else {
                core_1.CliUx.ux.action.stop('Unfortunately, the faucet request failed. Please try again later.');
            }
            this.exit(1);
        }
        core_1.CliUx.ux.action.stop('Success');
        this.log(`

    ${images_1.TWO_FISH_IMAGE}

Congratulations! The Iron Fish Faucet just added your request to the queue!

It will be processed within the next hour and $IRON will be sent directly to your account.

Check your balance by running:
  - ironfish wallet:balance

Learn how to send a transaction by running:
  - ironfish wallet:send --help`);
    }
}
FaucetCommand.description = `Receive coins from the Iron Fish official testnet Faucet`;
FaucetCommand.flags = {
    ...flags_1.RemoteFlags,
    force: core_1.Flags.boolean({
        default: false,
        description: 'Force the faucet to try to give you coins even if its disabled',
    }),
    email: core_1.Flags.string({
        hidden: true,
        description: 'Email to use to get funds',
    }),
};
exports.FaucetCommand = FaucetCommand;
//# sourceMappingURL=faucet.js.map