"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeeCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../command");
const flags_1 = require("../flags");
class FeeCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(FeeCommand);
        const client = await this.sdk.connectRpc();
        if (flags.explain) {
            await this.explainFeeRates(client);
        }
        const feeRates = await client.chain.estimateFeeRates();
        this.log('Fee Rates ($ORE/kB)');
        this.log(`slow:    ${feeRates.content.slow || ''}`);
        this.log(`average: ${feeRates.content.average || ''}`);
        this.log(`fast:    ${feeRates.content.fast || ''}`);
    }
    async explainFeeRates(client) {
        const config = await client.config.getConfig();
        const slow = config.content['feeEstimatorPercentileSlow'] || sdk_1.DEFAULT_FEE_ESTIMATOR_PERCENTILE_SLOW;
        const average = config.content['feeEstimatorPercentileAverage'] ||
            sdk_1.DEFAULT_FEE_ESTIMATOR_PERCENTILE_AVERAGE;
        const fast = config.content['feeEstimatorPercentileFast'] || sdk_1.DEFAULT_FEE_ESTIMATOR_PERCENTILE_FAST;
        const numBlocks = config.content['feeEstimatorMaxBlockHistory'] || sdk_1.DEFAULT_FEE_ESTIMATOR_MAX_BLOCK_HISTORY;
        this.log(`Fee rates are estimated from the distribution of transaction fees over the last ${numBlocks} blocks.\n`);
        this.log('The fee rate for each transaction is computed by dividing the transaction fee in $ORE by the size of the transaction in kB.\n');
        this.log('The slow, average, and fast rates each come from a percentile in the distribution:');
        this.log(`slow:    ${slow}th`);
        this.log(`average: ${average}th`);
        this.log(`fast:    ${fast}th`);
        this.log('');
    }
}
FeeCommand.description = `Get fee distribution for most recent blocks`;
FeeCommand.flags = {
    ...flags_1.RemoteFlags,
    explain: core_1.Flags.boolean({
        default: false,
        description: 'Explain fee rates',
    }),
};
exports.FeeCommand = FeeCommand;
//# sourceMappingURL=fees.js.map