"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const command_1 = require("../command");
const flags_1 = require("../flags");
class LogsCommand extends command_1.IronfishCommand {
    constructor() {
        super(...arguments);
        this.node = null;
    }
    async start() {
        await this.parse(LogsCommand);
        await this.sdk.client.connect();
        const response = this.sdk.client.node.getLogStream();
        for await (const value of response.contentStream()) {
            let parsedArgs;
            try {
                parsedArgs = sdk_1.IJSON.parse(value.args);
            }
            catch (e) {
                this.logger.error(`Failed to deserialize args: ${value.args}`);
                throw e;
            }
            sdk_1.ConsoleReporterInstance.log({
                level: Number(value.level),
                type: value.type,
                tag: value.tag,
                args: parsedArgs,
                date: new Date(value.date),
            });
        }
        this.exit(0);
    }
}
LogsCommand.description = 'Tail server logs';
LogsCommand.flags = {
    ...flags_1.RemoteFlags,
};
exports.default = LogsCommand;
//# sourceMappingURL=logs.js.map