"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const blessed_1 = __importDefault(require("blessed"));
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class Status extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(Status);
        if (!flags.follow) {
            const client = await this.sdk.connectRpc();
            const response = await client.mempool.getMempoolStatus();
            this.log(renderStatus(response.content));
            this.exit(0);
        }
        // Console log will create display issues with Blessed
        this.logger.pauseLogs();
        const screen = blessed_1.default.screen({ smartCSR: true });
        const statusText = blessed_1.default.text();
        screen.append(statusText);
        // eslint-disable-next-line no-constant-condition
        while (true) {
            const connected = await this.sdk.client.tryConnect();
            if (!connected) {
                statusText.clearBaseLine(0);
                statusText.setContent('Node: STOPPED');
                screen.render();
                await sdk_1.PromiseUtils.sleep(1000);
                continue;
            }
            const response = this.sdk.client.mempool.getMempoolStatusStream();
            for await (const value of response.contentStream()) {
                statusText.setContent(renderStatus(value));
                screen.render();
            }
        }
    }
}
Status.description = 'Show the status of the Mempool';
Status.flags = {
    ...flags_1.RemoteFlags,
    follow: core_1.Flags.boolean({
        char: 'f',
        default: false,
        description: 'Follow the status of the mempool live',
    }),
};
exports.default = Status;
function renderStatus(content) {
    const storage = sdk_1.FileUtils.formatMemorySize(content.sizeBytes);
    const maxStorage = sdk_1.FileUtils.formatMemorySize(content.maxSizeBytes);
    const saturationPercentage = ((content.sizeBytes / content.maxSizeBytes) * 100).toFixed(2);
    return `\
Tx Count           ${content.size}
Memory             ${storage} / ${maxStorage} (${saturationPercentage}%)
Eviction Cache     ${content.recentlyEvictedCache.size} / ${content.recentlyEvictedCache.maxSize}
Evictions          ${content.evictions}
Head Sequence      ${content.headSequence}`;
}
//# sourceMappingURL=status.js.map