"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AddCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class AddCommand extends command_1.IronfishCommand {
    async start() {
        const { args } = await this.parse(AddCommand);
        const address = args.address;
        const connected = await this.sdk.client.tryConnect();
        if (!connected) {
            this.log('Could not connect to node');
            this.exit(0);
        }
        if (!address.hostname) {
            this.error(`Could not parse the given url`);
        }
        const request = {
            host: address.hostname,
            port: address.port || sdk_1.DEFAULT_WEBSOCKET_PORT,
            whitelist: true,
        };
        const response = await this.sdk.client.peer.addPeer(request);
        if (response.content.added) {
            this.log(`Successfully added peer ${request.host}:${request.port}`);
        }
        else if (response.content.error !== undefined) {
            this.log(`Failed to add peer ${request.host}:${request.port} because: ${response.content.error}`);
            this.exit(0);
        }
        else {
            this.log(`Could not add peer ${request.host}:${request.port}`);
            this.exit(0);
        }
    }
}
AddCommand.description = `Attempt to connect to a peer through websockets`;
AddCommand.args = [
    {
        name: 'address',
        parse: (input) => Promise.resolve((0, sdk_1.parseUrl)(input.trim())),
        required: true,
        description: `The address of the peer to connect to in the form {host}:{port}`,
    },
];
AddCommand.flags = {
    ...flags_1.RemoteFlags,
};
exports.AddCommand = AddCommand;
//# sourceMappingURL=add.js.map