"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BannedCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const blessed_1 = __importDefault(require("blessed"));
const command_1 = require("../../command");
const flags_1 = require("../../flags");
const { sort, ...tableFlags } = core_1.CliUx.ux.table.flags();
class BannedCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(BannedCommand);
        if (!flags.follow) {
            await this.sdk.client.connect();
            const response = await this.sdk.client.peer.getBannedPeers();
            this.log(renderTable(response.content));
            this.exit(0);
        }
        // Console log will create display issues with Blessed
        this.logger.pauseLogs();
        const screen = blessed_1.default.screen({ smartCSR: true, fullUnicode: true });
        const text = blessed_1.default.text();
        screen.append(text);
        // eslint-disable-next-line no-constant-condition
        while (true) {
            const connected = await this.sdk.client.tryConnect();
            if (!connected) {
                text.clearBaseLine(0);
                text.setContent('Connecting...');
                screen.render();
                await sdk_1.PromiseUtils.sleep(1000);
                continue;
            }
            const response = this.sdk.client.peer.getBannedPeersStream();
            for await (const value of response.contentStream()) {
                text.clearBaseLine(0);
                text.setContent(renderTable(value));
                screen.render();
            }
        }
    }
}
BannedCommand.description = `List all banned peers`;
BannedCommand.flags = {
    ...flags_1.RemoteFlags,
    ...tableFlags,
    sort: {
        ...sort,
        exclusive: ['follow'],
    },
    follow: core_1.Flags.boolean({
        char: 'f',
        default: false,
        description: 'Follow the banned peers list live',
    }),
};
exports.BannedCommand = BannedCommand;
function renderTable(content) {
    const columns = {
        identity: {
            minWidth: 45,
            header: 'IDENTITY',
            get: (row) => {
                return row.identity;
            },
        },
        reason: {
            minWidth: 15,
            header: 'BAN REASON',
            get: (row) => {
                return row.reason;
            },
        },
    };
    let result = '';
    core_1.CliUx.ux.table(content.peers, columns, {
        printLine: (line) => (result += `${String(line)}\n`),
    });
    return result;
}
//# sourceMappingURL=banned.js.map