"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShowCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const safe_1 = __importDefault(require("colors/safe"));
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class ShowCommand extends command_1.IronfishCommand {
    async start() {
        const { args } = await this.parse(ShowCommand);
        const identity = args.identity.trim();
        await this.sdk.client.connect();
        const [peer, messages] = await Promise.all([
            this.sdk.client.peer.getPeer({ identity }),
            this.sdk.client.peer.getPeerMessages({ identity }),
        ]);
        if (peer.content.peer === null) {
            this.log(`No peer found containing identity '${identity}'.`);
            return this.exit(1);
        }
        this.log(this.renderPeer(peer.content.peer));
        if (messages.content.messages.length === 0) {
            this.log('No messages sent or received. Did you start your node with --logPeerMessages?');
        }
        else {
            for (const message of messages.content.messages) {
                this.log(this.renderMessage(message));
            }
        }
        this.exit(0);
    }
    renderPeer(peer) {
        return `Identity: ${String(peer.identity)}\nState: ${peer.state}`;
    }
    renderMessage(message) {
        const time = sdk_1.TimeUtils.renderTime(message.timestamp);
        const direction = safe_1.default.yellow(message.direction === 'send' ? 'SEND' : 'RECV');
        const type = message.brokeringPeerDisplayName
            ? `(broker: ${message.brokeringPeerDisplayName}) ${message.type}`
            : message.type;
        const messageType = safe_1.default.cyan(message.message.type.toString());
        const payload = message.message.payload;
        return `${time} ${direction} ${type}: ${messageType} ${payload}`;
    }
}
ShowCommand.description = `Display info about a peer`;
ShowCommand.args = [
    {
        name: 'identity',
        required: true,
        description: 'Identity of the peer',
    },
];
ShowCommand.flags = {
    ...flags_1.RemoteFlags,
};
exports.ShowCommand = ShowCommand;
//# sourceMappingURL=show.js.map