"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const promises_1 = __importDefault(require("fs/promises"));
const node_repl_1 = __importDefault(require("node:repl"));
const path_1 = __importDefault(require("path"));
const command_1 = require("../command");
const flags_1 = require("../flags");
class Repl extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(Repl);
        const node = await this.sdk.node();
        const client = new sdk_1.RpcMemoryClient(this.logger, node.rpc.getRouter(sdk_1.ALL_API_NAMESPACES));
        if (flags.opendb) {
            await sdk_1.NodeUtils.waitForOpen(node);
        }
        this.log('Examples:');
        this.log('  Get the head block hash');
        this.log(`  > chain.head.hash.toString('hex')`);
        this.log('\n  Get the head block sequence');
        this.log(`  > chain.head.sequence`);
        this.log('\n  Get a block at a sequence');
        this.log(`  > await chain.getHeaderAtSequence(1)`);
        this.log('\n  List all account names');
        this.log(`  > wallet.listAccounts().map((a) => a.name)`);
        this.log(`\n  Get the balance of an account`);
        this.log(`  > const account = await wallet.getAccountByName('default')`);
        this.log(`  > await wallet.getBalances(account)`);
        this.log(`\n  Use the RPC node/getStatus`);
        this.log(`  > (await client.status()).content`);
        this.log('');
        const historyPath = path_1.default.join(node.config.tempDir, 'repl_history.txt');
        await promises_1.default.mkdir(node.config.tempDir, { recursive: true });
        this.log(`Storing repl history at ${historyPath}`);
        this.log('Type .exit or press CTRL+C to quit');
        const server = node_repl_1.default.start('> ');
        server.context.sdk = this.sdk;
        server.context.client = client;
        server.context.node = node;
        server.context.chain = node.chain;
        server.context.wallet = node.wallet;
        server.context.memPool = node.memPool;
        // Setup command history file
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        server.setupHistory(historyPath, () => { });
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        await new Promise(() => { });
    }
}
Repl.description = 'An interactive terminal to the node';
Repl.flags = {
    [flags_1.VerboseFlagKey]: flags_1.VerboseFlag,
    [flags_1.ConfigFlagKey]: flags_1.ConfigFlag,
    [flags_1.DataDirFlagKey]: flags_1.DataDirFlag,
    opendb: core_1.Flags.boolean({
        description: 'open the databases',
        allowNo: true,
    }),
};
exports.default = Repl;
//# sourceMappingURL=repl.js.map