"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const promises_1 = __importDefault(require("fs/promises"));
const command_1 = require("../command");
const flags_1 = require("../flags");
class Reset extends command_1.IronfishCommand {
    constructor() {
        super(...arguments);
        this.node = null;
    }
    async start() {
        const { flags } = await this.parse(Reset);
        const chainDatabasePath = this.sdk.config.chainDatabasePath;
        const hostFilePath = this.sdk.config.files.join(this.sdk.config.dataDir, sdk_1.PEER_STORE_FILE_NAME);
        const existingId = this.sdk.internal.get('networkId');
        let networkIdMessage = '';
        if (flags.networkId != null && flags.networkId !== existingId) {
            networkIdMessage = `\n\nThe network ID will be changed from ${existingId} to the new value of ${flags.networkId}`;
        }
        else {
            networkIdMessage = `\n\nThe network ID will stay unchanged as ${existingId}`;
        }
        const message = '\nYou are about to destroy your local copy of the blockchain. The following directories and files will be deleted:\n' +
            `\nBlockchain: ${chainDatabasePath}` +
            `\nHosts: ${hostFilePath}` +
            '\nYour wallet, accounts, and keys will NOT be deleted.' +
            networkIdMessage +
            `\n\nAre you sure? (Y)es / (N)o`;
        const confirmed = flags.confirm || (await core_1.CliUx.ux.confirm(message));
        if (!confirmed) {
            this.log('Reset aborted.');
            this.exit(0);
        }
        core_1.CliUx.ux.action.start('Deleting databases...');
        await Promise.all([
            promises_1.default.rm(chainDatabasePath, { recursive: true, force: true }),
            promises_1.default.rm(hostFilePath, { recursive: true, force: true }),
        ]);
        let networkChanged = false;
        if (flags.networkId != null && flags.networkId !== existingId) {
            this.sdk.internal.set('networkId', flags.networkId);
            networkChanged = true;
        }
        this.sdk.internal.set('isFirstRun', true);
        await this.sdk.internal.save();
        const node = await this.sdk.node();
        await node.wallet.open();
        await node.wallet.reset({ resetCreatedAt: networkChanged });
        core_1.CliUx.ux.action.stop('Databases deleted successfully');
    }
}
Reset.description = 'Reset the node to its initial state';
Reset.flags = {
    [flags_1.VerboseFlagKey]: flags_1.VerboseFlag,
    [flags_1.ConfigFlagKey]: flags_1.ConfigFlag,
    [flags_1.DataDirFlagKey]: flags_1.DataDirFlag,
    networkId: core_1.Flags.integer({
        char: 'i',
        default: undefined,
        description: 'Network ID of an official Iron Fish network to connect to',
    }),
    confirm: core_1.Flags.boolean({
        default: false,
        description: 'Confirm without asking',
    }),
};
exports.default = Reset;
//# sourceMappingURL=reset.js.map