"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class Token extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(Token);
        const internal = this.sdk.internal;
        const token = internal.get('rpcAuthToken');
        if (flags.token) {
            internal.set('rpcAuthToken', flags.token);
            await internal.save();
            this.log(`RPC auth token changed from ${token} to ${flags.token}`);
        }
        else {
            if (token) {
                this.log(`RPC auth token: ${token}`);
            }
            else {
                this.log('No RPC auth token found.');
            }
        }
    }
}
Token.description = 'Get or set the RPC auth token';
Token.flags = {
    ...flags_1.LocalFlags,
    token: core_1.Flags.string({
        parse: (input) => Promise.resolve(input.trim()),
        required: false,
        description: 'Set the RPC auth token to <value>',
    }),
};
exports.default = Token;
//# sourceMappingURL=token.js.map