"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../command");
const images_1 = require("../images");
const FRAME_RATE_MS = 1000 / 30;
class SwimCommand extends command_1.IronfishCommand {
    async start() {
        await this.parse(SwimCommand);
        const images = [images_1.ONE_FISH_IMAGE, images_1.TWO_FISH_IMAGE];
        const image = images[Math.round(Math.random() * (images.length - 1))];
        const pixels = this.getPixels(image);
        let last = Date.now();
        let elapsed = 0;
        for (;;) {
            // Calculate elapsed time for calculating elapsed frames
            const now = Date.now();
            elapsed += now - last;
            last = now;
            // Calculate elapsed frames
            let frames = Math.floor(elapsed / FRAME_RATE_MS);
            elapsed -= FRAME_RATE_MS * frames;
            // Update for each elapsed frame
            while (frames-- > 0) {
                pixels.unshift(pixels.pop());
            }
            // Render the current frame
            // eslint-disable-next-line no-console
            console.clear();
            this.renderPixels(pixels);
            this.log('The hex fish are coming...');
            await core_1.CliUx.ux.wait(32);
        }
        // eslint-disable-next-line no-console
        console.clear();
    }
    getPixels(image) {
        const rows = image.split('\n');
        const rowToGetWidth = Math.round(rows.length / 2);
        const width = rows[rowToGetWidth].length;
        const height = rows.length;
        const pixels = new Array();
        for (let x = 0; x < width; ++x) {
            const col = [];
            for (let y = 0; y < height; ++y) {
                col.push(rows[y][x]);
            }
            pixels.push(col);
        }
        return pixels;
    }
    renderPixels(pixels) {
        const rows = new Array();
        const height = pixels[0].length;
        const width = pixels.length;
        for (let y = 0; y < height; ++y) {
            const row = [];
            for (let x = 0; x < width; ++x) {
                row.push(pixels[x][y]);
            }
            rows.push(row.join(''));
        }
        this.log(rows.join('\n'));
    }
}
SwimCommand.description = 'See the hex fish swim';
SwimCommand.hidden = true;
exports.default = SwimCommand;
//# sourceMappingURL=swim.js.map