"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccountsCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class AccountsCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(AccountsCommand);
        const client = await this.sdk.connectRpc();
        const response = await client.wallet.getAccounts({ displayName: flags.displayName });
        if (response.content.accounts.length === 0) {
            this.log('you have no accounts');
        }
        for (const name of response.content.accounts) {
            this.log(name);
        }
    }
}
AccountsCommand.description = `List all the accounts on the node`;
AccountsCommand.flags = {
    ...flags_1.RemoteFlags,
    displayName: core_1.Flags.boolean({
        default: false,
        description: `Display a hash of the account's read-only keys along with the account name`,
    }),
};
exports.AccountsCommand = AccountsCommand;
//# sourceMappingURL=accounts.js.map