"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AddressCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class AddressCommand extends command_1.IronfishCommand {
    async start() {
        const { args } = await this.parse(AddressCommand);
        const account = args.account;
        const client = await this.sdk.connectRpc();
        const response = await client.wallet.getAccountPublicKey({
            account: account,
        });
        if (!response) {
            this.error(`An error occurred while fetching the public key.`);
        }
        this.log(`Account: ${response.content.account}, public key: ${response.content.publicKey}`);
    }
}
AddressCommand.description = `Display your account address

  The address for an account is the accounts public key, see more here: https://ironfish.network/docs/whitepaper/5_account`;
AddressCommand.flags = {
    ...flags_1.RemoteFlags,
};
AddressCommand.args = [
    {
        name: 'account',
        required: false,
        description: 'Name of the account to get the address for',
    },
];
exports.AddressCommand = AddressCommand;
//# sourceMappingURL=address.js.map