"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateCommand = void 0;
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class CreateCommand extends command_1.IronfishCommand {
    async start() {
        const { args } = await this.parse(CreateCommand);
        let name = args.account;
        if (!name) {
            name = await core_1.CliUx.ux.prompt('Enter the name of the account', {
                required: true,
            });
        }
        const client = await this.sdk.connectRpc();
        this.log(`Creating account ${name}`);
        const result = await client.wallet.createAccount({ name });
        const { publicAddress, isDefaultAccount } = result.content;
        this.log(`Account ${name} created with public address ${publicAddress}`);
        if (isDefaultAccount) {
            this.log(`The default account is now: ${name}`);
        }
        else {
            this.log(`Run "ironfish wallet:use ${name}" to set the account as default`);
        }
    }
}
CreateCommand.description = `Create a new account for sending and receiving coins`;
CreateCommand.args = [
    {
        name: 'account',
        required: false,
        description: 'Name of the account',
    },
];
CreateCommand.flags = {
    ...flags_1.RemoteFlags,
};
exports.CreateCommand = CreateCommand;
//# sourceMappingURL=create.js.map