"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeleteCommand = void 0;
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class DeleteCommand extends command_1.IronfishCommand {
    async start() {
        const { args, flags } = await this.parse(DeleteCommand);
        const confirm = flags.confirm;
        const wait = flags.wait;
        const account = args.account;
        const client = await this.sdk.connectRpc();
        core_1.CliUx.ux.action.start(`Deleting account '${account}'`);
        const response = await client.wallet.removeAccount({ account, confirm, wait });
        core_1.CliUx.ux.action.stop();
        if (response.content.needsConfirm) {
            const value = await core_1.CliUx.ux.prompt(`Are you sure? Type ${account} to confirm`);
            if (value !== account) {
                this.log(`Aborting: ${value} did not match ${account}`);
                this.exit(1);
            }
            core_1.CliUx.ux.action.start(`Deleting account '${account}'`);
            await client.wallet.removeAccount({ account, confirm: true, wait });
            core_1.CliUx.ux.action.stop();
        }
        this.log(`Account '${account}' successfully deleted.`);
    }
}
DeleteCommand.description = `Permanently delete an account`;
DeleteCommand.args = [
    {
        name: 'account',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'Name of the account',
    },
];
DeleteCommand.flags = {
    ...flags_1.RemoteFlags,
    confirm: core_1.Flags.boolean({
        description: 'Suppress the confirmation prompt',
    }),
    wait: core_1.Flags.boolean({
        description: 'Wait for the account to be deleted, rather than the default of marking the account for deletion then returning immediately',
    }),
};
exports.DeleteCommand = DeleteCommand;
//# sourceMappingURL=delete.js.map