"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotesCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../../../command");
const flags_1 = require("../../../flags");
const table_1 = require("../../../utils/table");
const { sort: _, ...tableFlags } = core_1.CliUx.ux.table.flags();
class NotesCommand extends command_1.IronfishCommand {
    async start() {
        const { flags, args } = await this.parse(NotesCommand);
        const account = args.account;
        const client = await this.sdk.connectRpc();
        const response = client.wallet.getAccountNotesStream({ account });
        let showHeader = !flags['no-header'];
        for await (const note of response.contentStream()) {
            core_1.CliUx.ux.table([note], {
                memo: {
                    header: 'Memo',
                    // Maximum memo length is 32 bytes
                    minWidth: 33,
                },
                sender: {
                    header: 'Sender',
                },
                transactionHash: {
                    header: 'From Transaction',
                },
                isSpent: {
                    header: 'Spent',
                    get: (row) => {
                        if (row.spent === undefined) {
                            return '-';
                        }
                        else {
                            return row.spent ? `✔` : `x`;
                        }
                    },
                },
                ...table_1.TableCols.asset({ extended: flags.extended }),
                value: {
                    header: 'Amount',
                    get: (row) => sdk_1.CurrencyUtils.renderIron(row.value),
                    minWidth: 16,
                },
                noteHash: {
                    header: 'Note Hash',
                },
                nullifier: {
                    header: 'Nullifier',
                    get: (row) => {
                        if (row.nullifier === null) {
                            return '-';
                        }
                        else {
                            return row.nullifier;
                        }
                    },
                },
            }, { ...flags, 'no-header': !showHeader });
            showHeader = false;
        }
    }
}
NotesCommand.description = `Display the account notes`;
NotesCommand.flags = {
    ...flags_1.RemoteFlags,
    ...tableFlags,
};
NotesCommand.args = [
    {
        name: 'account',
        required: false,
        description: 'Name of the account to get notes for',
    },
];
exports.NotesCommand = NotesCommand;
//# sourceMappingURL=index.js.map