"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class PruneCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(PruneCommand);
        core_1.CliUx.ux.action.start(`Opening node`);
        const node = await this.sdk.node();
        await sdk_1.NodeUtils.waitForOpen(node);
        core_1.CliUx.ux.action.stop('Done.');
        if (flags.expire) {
            for (const account of node.wallet.listAccounts()) {
                const head = await account.getHead();
                if (head !== null) {
                    this.log(`Process Account ${account.displayName}.`);
                    let count = 0;
                    for await (const transactionValue of account.getTransactions()) {
                        const status = await node.wallet.getTransactionStatus(account, transactionValue);
                        if (status === sdk_1.TransactionStatus.EXPIRED) {
                            count = +1;
                            if (flags.dryrun === false) {
                                await account.deleteTransaction(transactionValue.transaction);
                            }
                        }
                    }
                    this.log(`Account ${account.displayName} has ${count} expired transactions`);
                }
            }
        }
        core_1.CliUx.ux.action.start(`Cleaning up deleted accounts`);
        await node.wallet.forceCleanupDeletedAccounts();
        core_1.CliUx.ux.action.stop();
        if (flags.compact) {
            core_1.CliUx.ux.action.start(`Compacting wallet database`);
            await node.wallet.walletDb.db.compact();
            core_1.CliUx.ux.action.stop();
        }
        await node.closeDB();
    }
}
PruneCommand.description = 'Removes expired transactions from the wallet';
PruneCommand.hidden = false;
PruneCommand.flags = {
    ...flags_1.LocalFlags,
    dryrun: core_1.Flags.boolean({
        default: false,
        description: 'Dry run prune first',
    }),
    expire: core_1.Flags.boolean({
        char: 'e',
        default: true,
        allowNo: true,
        description: 'Delete expired transactions from the wallet',
    }),
    compact: core_1.Flags.boolean({
        char: 'c',
        default: true,
        allowNo: true,
        description: 'Compact the database',
    }),
};
exports.default = PruneCommand;
//# sourceMappingURL=prune.js.map