"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class StatusCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(StatusCommand);
        const client = await this.sdk.connectRpc();
        const response = await client.wallet.getAccountsStatus();
        core_1.CliUx.ux.table(response.content.accounts, {
            name: {
                header: 'Account Name',
                minWidth: 11,
            },
            id: {
                header: 'Account ID',
            },
            viewOnly: {
                header: 'View Only',
            },
            headHash: {
                get: (row) => row.head?.hash ?? 'NULL',
                header: 'Head Hash',
            },
            headInChain: {
                get: (row) => row.head?.inChain ?? 'NULL',
                header: 'Head In Chain',
            },
            sequence: {
                get: (row) => row.head?.sequence ?? 'NULL',
                header: 'Head Sequence',
            },
        }, {
            printLine: this.log.bind(this),
            ...flags,
        });
    }
}
StatusCommand.description = `Get status of all accounts`;
StatusCommand.flags = {
    ...flags_1.RemoteFlags,
    ...core_1.CliUx.ux.table.flags(),
};
exports.StatusCommand = StatusCommand;
//# sourceMappingURL=status.js.map