"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransactionAddCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../../command");
const flags_1 = require("../../../flags");
class TransactionAddCommand extends command_1.IronfishCommand {
    async start() {
        const { flags, args } = await this.parse(TransactionAddCommand);
        const transaction = args.transaction;
        core_1.CliUx.ux.action.start(`Adding transaction`);
        const client = await this.sdk.connectRpc();
        const response = await client.wallet.addTransaction({
            transaction,
            broadcast: flags.broadcast,
        });
        core_1.CliUx.ux.action.stop();
        this.log(`Transaction added for accounts: ${response.content.accounts.join(', ')}`);
    }
}
TransactionAddCommand.description = `Add a transaction to your wallet`;
TransactionAddCommand.flags = {
    ...flags_1.RemoteFlags,
    broadcast: core_1.Flags.boolean({
        default: true,
        allowNo: true,
        description: 'Broadcast the transaction to the network after adding',
    }),
};
TransactionAddCommand.args = [
    {
        name: 'transaction',
        required: true,
        parse: (input) => Promise.resolve(input.trim()),
        description: 'The transaction in hex encoding',
    },
];
exports.TransactionAddCommand = TransactionAddCommand;
//# sourceMappingURL=add.js.map