"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WatchTxCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../../command");
const flags_1 = require("../../../flags");
const transaction_1 = require("../../../utils/transaction");
class WatchTxCommand extends command_1.IronfishCommand {
    async start() {
        const { flags, args } = await this.parse(WatchTxCommand);
        const hash = args.hash;
        const account = args.account;
        const client = await this.sdk.connectRpc();
        await (0, transaction_1.watchTransaction)({
            client,
            logger: this.logger,
            account,
            hash,
            confirmations: flags.confirmations,
        });
    }
}
WatchTxCommand.description = `Display an account transaction`;
WatchTxCommand.flags = {
    ...flags_1.RemoteFlags,
    confirmations: core_1.Flags.integer({
        required: false,
        description: 'Minimum number of blocks confirmations for a transaction',
    }),
};
WatchTxCommand.args = [
    {
        name: 'hash',
        parse: (input) => Promise.resolve(input.trim()),
        required: true,
        description: 'Hash of the transaction',
    },
    {
        name: 'account',
        required: false,
        description: 'Name of the account',
    },
];
exports.WatchTxCommand = WatchTxCommand;
//# sourceMappingURL=watch.js.map