"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhichCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../command");
const flags_1 = require("../../flags");
class WhichCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(WhichCommand);
        const client = await this.sdk.connectRpc();
        const { content: { accounts: [accountName], }, } = await client.wallet.getAccounts({ default: true, displayName: flags.displayName });
        if (!accountName) {
            this.log('There is currently no account being used.\n' +
                ' * Create an account: "ironfish wallet:create"\n' +
                ' * List all accounts: "ironfish wallet:accounts"\n' +
                ' * Use an existing account: "ironfish wallet:use <name>"');
            this.exit(0);
        }
        this.log(accountName);
    }
}
WhichCommand.description = `Show the account currently used.

  By default all commands will use this account when deciding what
  keys to use. If no account is specified as the default, you must
  specify the account in the command using --account <name>`;
WhichCommand.flags = {
    ...flags_1.RemoteFlags,
    displayName: core_1.Flags.boolean({
        default: false,
        description: `Display a hash of the account's read-only keys along with the account name`,
    }),
};
exports.WhichCommand = WhichCommand;
//# sourceMappingURL=which.js.map