"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HexFlag = exports.parseIron = exports.IronFlag = exports.RemoteFlags = exports.LocalFlags = exports.RpcUseHttpFlag = exports.RpcHttpPortFlag = exports.RpcHttpHostFlag = exports.RpcAuthFlag = exports.RpcTcpTlsFlag = exports.RpcTcpPortFlag = exports.RpcTcpHostFlag = exports.RpcUseTcpFlag = exports.RpcUseIpcFlag = exports.DataDirFlag = exports.ConfigFlag = exports.ColorFlag = exports.VerboseFlag = exports.RpcAuthFlagKey = exports.RpcTcpTlsFlagKey = exports.RpcHttpPortFlagKey = exports.RpcHttpHostFlagKey = exports.RpcUseHttpFlagKey = exports.RpcTcpPortFlagKey = exports.RpcTcpHostFlagKey = exports.RpcUseTcpFlagKey = exports.RpcUseIpcFlagKey = exports.DataDirFlagKey = exports.ColorFlagKey = exports.ConfigFlagKey = exports.VerboseFlagKey = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
exports.VerboseFlagKey = 'verbose';
exports.ConfigFlagKey = 'config';
exports.ColorFlagKey = 'color';
exports.DataDirFlagKey = 'datadir';
exports.RpcUseIpcFlagKey = 'rpc.ipc';
exports.RpcUseTcpFlagKey = 'rpc.tcp';
exports.RpcTcpHostFlagKey = 'rpc.tcp.host';
exports.RpcTcpPortFlagKey = 'rpc.tcp.port';
exports.RpcUseHttpFlagKey = 'rpc.http';
exports.RpcHttpHostFlagKey = 'rpc.http.host';
exports.RpcHttpPortFlagKey = 'rpc.http.port';
exports.RpcTcpTlsFlagKey = 'rpc.tcp.tls';
exports.RpcAuthFlagKey = 'rpc.auth';
exports.VerboseFlag = core_1.Flags.boolean({
    char: 'v',
    default: false,
    description: 'Set logging level to verbose',
});
exports.ColorFlag = core_1.Flags.boolean({
    default: true,
    allowNo: true,
    description: 'Should colorize the output',
});
exports.ConfigFlag = core_1.Flags.string({
    default: sdk_1.DEFAULT_CONFIG_NAME,
    description: 'The name of the config file to use',
});
exports.DataDirFlag = core_1.Flags.string({
    char: 'd',
    default: sdk_1.DEFAULT_DATA_DIR,
    description: 'The path to the data dir',
    env: 'IRONFISH_DATA_DIR',
});
exports.RpcUseIpcFlag = core_1.Flags.boolean({
    default: sdk_1.DEFAULT_USE_RPC_IPC,
    description: 'Connect to the RPC over IPC (default)',
});
exports.RpcUseTcpFlag = core_1.Flags.boolean({
    default: sdk_1.DEFAULT_USE_RPC_TCP,
    description: 'Connect to the RPC over TCP',
});
exports.RpcTcpHostFlag = core_1.Flags.string({
    description: 'The TCP host to listen for connections on',
});
exports.RpcTcpPortFlag = core_1.Flags.integer({
    description: 'The TCP port to listen for connections on',
});
exports.RpcTcpTlsFlag = core_1.Flags.boolean({
    default: sdk_1.DEFAULT_USE_RPC_TLS,
    description: 'Encrypt TCP connection to the RPC over TLS',
    allowNo: true,
});
exports.RpcAuthFlag = core_1.Flags.string({
    description: 'The RPC auth token',
});
exports.RpcHttpHostFlag = core_1.Flags.string({
    description: 'The HTTP host to listen for connections on',
});
exports.RpcHttpPortFlag = core_1.Flags.integer({
    description: 'The HTTP port to listen for connections on',
});
exports.RpcUseHttpFlag = core_1.Flags.boolean({
    default: sdk_1.DEFAULT_USE_RPC_HTTP,
    description: 'Connect to the RPC over HTTP',
    allowNo: true,
});
const localFlags = {};
localFlags[exports.VerboseFlagKey] = exports.VerboseFlag;
localFlags[exports.ConfigFlagKey] = exports.ConfigFlag;
localFlags[exports.DataDirFlagKey] = exports.DataDirFlag;
/**
 * These flags should usually be used on any command that starts a node,
 * or uses a database to execute the command
 */
exports.LocalFlags = localFlags;
const remoteFlags = {};
remoteFlags[exports.VerboseFlagKey] = exports.VerboseFlag;
remoteFlags[exports.ConfigFlagKey] = exports.ConfigFlag;
remoteFlags[exports.DataDirFlagKey] = exports.DataDirFlag;
remoteFlags[exports.RpcUseTcpFlagKey] = exports.RpcUseTcpFlag;
remoteFlags[exports.RpcUseIpcFlagKey] = exports.RpcUseIpcFlag;
remoteFlags[exports.RpcTcpHostFlagKey] = exports.RpcTcpHostFlag;
remoteFlags[exports.RpcTcpPortFlagKey] = exports.RpcTcpPortFlag;
remoteFlags[exports.RpcHttpHostFlagKey] = exports.RpcHttpHostFlag;
remoteFlags[exports.RpcHttpPortFlagKey] = exports.RpcHttpPortFlag;
remoteFlags[exports.RpcUseHttpFlagKey] = exports.RpcUseHttpFlag;
remoteFlags[exports.RpcTcpTlsFlagKey] = exports.RpcTcpTlsFlag;
remoteFlags[exports.RpcAuthFlagKey] = exports.RpcAuthFlag;
/**
 * These flags should usually be used on any command that uses an
 * RPC client to connect to a node to run the command
 */
exports.RemoteFlags = remoteFlags;
exports.IronFlag = core_1.Flags.custom({
    parse: async (input, _ctx, opts) => (0, exports.parseIron)(input, opts),
    char: 'i',
});
const parseIron = (input, opts) => {
    return new Promise((resolve, reject) => {
        const { minimum, flagName } = opts ?? {};
        try {
            const value = sdk_1.CurrencyUtils.decodeIron(input);
            if (minimum !== undefined && value < minimum) {
                reject(new Error(`The minimum ${flagName} is ${sdk_1.CurrencyUtils.renderOre(minimum, true)}`));
            }
            if (value < sdk_1.MINIMUM_ORE_AMOUNT || value > sdk_1.MAXIMUM_ORE_AMOUNT) {
                reject(new Error(`The number inputted for ${flagName} is invalid.`));
            }
            resolve(value);
        }
        catch {
            reject(new Error(`The number inputted for ${flagName} is invalid.`));
        }
    });
};
exports.parseIron = parseIron;
exports.HexFlag = core_1.Flags.custom({
    parse: async (input, _ctx, opts) => {
        const hexRegex = /^[0-9A-Fa-f]+$/g;
        if (!hexRegex.test(input)) {
            throw new Error(`The value provided for ${opts.name} is an invalid format. It must be a hex string.`);
        }
        return Promise.resolve(input);
    },
});
//# sourceMappingURL=flags.js.map