/// <reference types="node" />
import { S3Client } from '@aws-sdk/client-s3';
import { Logger, MessageBuffer } from '@ironfish/sdk';
import net from 'net';
import { CeremonyServerMessage } from './schema';
declare class CeremonyServerClient {
    id: string;
    socket: net.Socket;
    connected: boolean;
    logger: Logger;
    readonly messageBuffer: MessageBuffer;
    private _joined?;
    constructor(options: {
        socket: net.Socket;
        id: string;
        logger: Logger;
    });
    send(message: CeremonyServerMessage): void;
    join(name?: string): void;
    get joined(): boolean;
    get name(): string | undefined;
    close(error?: Error): void;
}
export declare class CeremonyServer {
    readonly server: net.Server;
    readonly logger: Logger;
    private stopPromise;
    private stopResolve;
    readonly port: number;
    readonly host: string;
    readonly s3Bucket: string;
    readonly downloadPrefix: string;
    private s3Client;
    readonly tempDir: string;
    private queue;
    private privateQueue;
    private currentContributor;
    readonly contributionTimeoutMs: number;
    readonly uploadTimeoutMs: number;
    readonly presignedExpirationSec: number;
    readonly startDate: number;
    private token;
    readonly enableIPBanning: boolean;
    constructor(options: {
        logger: Logger;
        port: number;
        host: string;
        s3Bucket: string;
        downloadPrefix: string;
        s3Client: S3Client;
        tempDir: string;
        contributionTimeoutMs: number;
        uploadTimeoutMs: number;
        presignedExpirationSec: number;
        startDate: number;
        token: string;
        enableIPBanning: boolean;
    });
    getLatestParamName(): Promise<string>;
    totalQueueLength(): number;
    closeClient(client: CeremonyServerClient, error?: Error, disconnect?: boolean): void;
    /** initiate a contributor if one does not already exist */
    startNextContributor(): Promise<void>;
    start(): Promise<void>;
    stop(): void;
    waitForStop(): Promise<void>;
    private onConnection;
    private onDisconnect;
    private onData;
    private handleContributionComplete;
    private getJoinedMessage;
    private sendUpdatedLocationsToClients;
    private handleUploadComplete;
}
export {};
//# sourceMappingURL=server.d.ts.map