"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const asset_1 = require("./asset");
describe('asset utils', () => {
    describe('compareAssets', () => {
        it('returns 1/0/-1 depending on sort order', () => {
            const verified = { status: 'verified' };
            const unverified = { status: 'unverified' };
            expect((0, asset_1.compareAssets)('a', verified, 'b', unverified)).toEqual(-1);
            expect((0, asset_1.compareAssets)('b', unverified, 'a', verified)).toEqual(1);
            expect((0, asset_1.compareAssets)('b', verified, 'a', unverified)).toEqual(-1);
            expect((0, asset_1.compareAssets)('a', unverified, 'b', verified)).toEqual(1);
            expect((0, asset_1.compareAssets)('a', verified, 'b', verified)).toEqual(-1);
            expect((0, asset_1.compareAssets)('b', verified, 'a', verified)).toEqual(1);
            expect((0, asset_1.compareAssets)('a', unverified, 'b', unverified)).toEqual(-1);
            expect((0, asset_1.compareAssets)('b', unverified, 'a', unverified)).toEqual(1);
            expect((0, asset_1.compareAssets)('a', verified, 'a', verified)).toEqual(0);
            expect((0, asset_1.compareAssets)('a', unverified, 'a', unverified)).toEqual(0);
        });
        it('can be used to sort assets by verified status first, and name second', () => {
            const verified = { status: 'verified' };
            const unverified = { status: 'unverified' };
            const unknown = { status: 'unknown' };
            const assets = [
                { name: 'aaa', verification: unknown },
                { name: 'bbb', verification: unverified },
                { name: 'ccc', verification: verified },
                { name: 'fff', verification: verified },
                { name: 'eee', verification: unverified },
                { name: 'ddd', verification: unknown },
            ];
            assets.sort((left, right) => (0, asset_1.compareAssets)(left.name, left.verification, right.name, right.verification));
            expect(assets).toStrictEqual([
                { name: 'ccc', verification: verified },
                { name: 'fff', verification: verified },
                { name: 'aaa', verification: unknown },
                { name: 'bbb', verification: unverified },
                { name: 'ddd', verification: unknown },
                { name: 'eee', verification: unverified },
            ]);
        });
    });
});
//# sourceMappingURL=asset.test.js.map