"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectFee = void 0;
const rust_nodejs_1 = require("@ironfish/rust-nodejs");
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const inquirer_1 = __importDefault(require("inquirer"));
const currency_1 = require("./currency");
async function selectFee(options) {
    core_1.CliUx.ux.action.start('Calculating fees');
    const feeRates = await options.client.wallet.estimateFeeRates();
    const promises = [
        getTxWithFee(options.client, options.transaction, sdk_1.CurrencyUtils.decode(feeRates.content.slow)),
        getTxWithFee(options.client, options.transaction, sdk_1.CurrencyUtils.decode(feeRates.content.average)),
        getTxWithFee(options.client, options.transaction, sdk_1.CurrencyUtils.decode(feeRates.content.fast)),
    ];
    const [slow, average, fast] = await Promise.all(promises);
    const choices = [
        getChoiceFromTx('Slow', slow),
        getChoiceFromTx('Average', average),
        getChoiceFromTx('Fast', fast),
        {
            name: 'Enter a custom fee',
            value: null,
        },
    ];
    core_1.CliUx.ux.action.stop();
    const result = await inquirer_1.default.prompt([
        {
            name: 'selection',
            message: `Select the fee you wish to use for this transaction`,
            type: 'list',
            choices,
        },
    ]);
    if (result.selection == null) {
        const fee = await (0, currency_1.promptCurrency)({
            client: options.client,
            required: true,
            text: 'Enter the fee amount in $IRON',
            logger: options.logger,
            balance: {
                account: options.account,
                confirmations: options.confirmations,
                assetId: rust_nodejs_1.Asset.nativeId().toString('hex'),
            },
        });
        const custom = await options.client.wallet.createTransaction({
            ...options.transaction,
            fee: sdk_1.CurrencyUtils.encode(fee),
        });
        const bytes = Buffer.from(custom.content.transaction, 'hex');
        return sdk_1.RawTransactionSerde.deserialize(bytes);
    }
    sdk_1.Assert.isInstanceOf(result.selection, sdk_1.RawTransaction);
    return result.selection;
}
exports.selectFee = selectFee;
async function getTxWithFee(client, params, feeRate) {
    const promise = client.wallet.createTransaction({
        ...params,
        feeRate: sdk_1.CurrencyUtils.encode(feeRate),
    });
    const response = await promise.catch((e) => {
        if (e instanceof sdk_1.RpcRequestError && e.code === sdk_1.ERROR_CODES.INSUFFICIENT_BALANCE) {
            return null;
        }
        else {
            throw e;
        }
    });
    if (response === null) {
        return null;
    }
    const bytes = Buffer.from(response.content.transaction, 'hex');
    const raw = sdk_1.RawTransactionSerde.deserialize(bytes);
    return raw;
}
function getChoiceFromTx(name, transaction) {
    return {
        name: `${name} ${transaction ? sdk_1.CurrencyUtils.renderIron(transaction.fee) : ''}`,
        disabled: transaction ? false : 'Not enough $IRON',
        value: transaction,
    };
}
//# sourceMappingURL=fees.js.map