"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GossipForkCounter = void 0;
const blru_1 = __importDefault(require("blru"));
class GossipForkCounter {
    constructor(targetBlockTimeInSeconds, options) {
        this.heads = new blru_1.default(5000, null, Map);
        this.tickInterval = null;
        this.active = [];
        this.delay = options?.delayMs ?? 1000;
        this.staleThreshold = targetBlockTimeInSeconds * 3 * 1000;
    }
    start() {
        this.tickInterval = setInterval(() => this.tick(), this.delay);
    }
    stop() {
        if (this.tickInterval) {
            clearInterval(this.tickInterval);
        }
    }
    tick() {
        const now = Date.now();
        const active = [];
        const values = [...this.heads.values()].sort((a, b) => b.header.sequence - a.header.sequence);
        for (const { header, timestamp, ageSequence, old } of values) {
            const age = now - timestamp;
            if (age >= this.staleThreshold) {
                continue;
            }
            if (old) {
                continue;
            }
            active.push({
                header,
                timestamp,
                ageSequence,
                age,
            });
        }
        this.active = active;
    }
    get latest() {
        return this.active[0] ?? null;
    }
    get count() {
        return this.active.length;
    }
    get forks() {
        return this.active;
    }
    add(header) {
        const prev = this.heads.get(header.previousBlockHash);
        const ageSequence = prev ? prev.ageSequence + 1 : 0;
        if (prev) {
            prev.old = true;
            this.heads.set(header.previousBlockHash, prev);
        }
        this.heads.set(header.hash, {
            header: header,
            timestamp: Date.now(),
            ageSequence,
        });
    }
}
exports.GossipForkCounter = GossipForkCounter;
//# sourceMappingURL=gossipForkCounter.js.map