"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlatformUtils = exports.browse = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const child_process_1 = require("child_process");
/**
 * Opens a resolved path in the OS specific explorer for a relevant path
 * On mac it uses finder, on windows it uses explorer.
 * @param dir The path or file to browse to
 * @returns false if the OS explorer could not be detected
 */
function browse(dir) {
    const platform = sdk_1.Platform.getName();
    switch (platform) {
        case 'win32':
            (0, child_process_1.spawn)('explorer', [dir]);
            break;
        case 'darwin':
            (0, child_process_1.spawn)('open', [dir]);
            break;
        default:
            return false;
    }
    return true;
}
exports.browse = browse;
exports.PlatformUtils = {
    browse,
};
//# sourceMappingURL=platform.js.map