import { DeleteObjectCommandOutput, HeadObjectCommandOutput, S3Client } from '@aws-sdk/client-s3';
import { Credentials } from '@aws-sdk/types/dist-types/credentials';
import { Logger } from '@ironfish/sdk';
export type R2Secret = {
    r2AccessKeyId: string;
    r2SecretAccessKey: string;
};
declare function uploadToBucket(s3: S3Client, filePath: string, contentType: string, bucket: string, keyName: string, logger?: Logger, metadata?: Record<string, string>): Promise<void>;
declare function downloadFromBucket(s3: S3Client, bucket: string, keyName: string, output: string): Promise<void>;
declare function getPresignedUploadUrl(s3: S3Client, bucket: string, keyName: string, expiresInSeconds: number): Promise<string>;
/**
 * Returns an HTTPS URL to a file in S3.
 * https://docs.aws.amazon.com/AmazonS3/latest/userguide/transfer-acceleration-getting-started.html
 * https://docs.aws.amazon.com/AmazonS3/latest/userguide/dual-stack-endpoints.html
 */
declare function getDownloadUrl(bucket: string, key: string, region: {
    accelerated: true;
} | {
    accelerated: false;
    regionCode: string;
}, options?: {
    dualStack?: boolean;
}): string;
declare function getObjectMetadata(s3: S3Client, bucket: string, key: string): Promise<HeadObjectCommandOutput>;
declare function getBucketObjects(s3: S3Client, bucket: string): Promise<string[]>;
declare function deleteFromBucket(s3Client: S3Client, bucket: string, fileName: string): Promise<DeleteObjectCommandOutput>;
declare function getS3Client(useDualstackEndpoint: boolean, credentials?: {
    accessKeyId: string;
    secretAccessKey: string;
}): S3Client;
declare function getR2S3Client(credentials: {
    r2AccessKeyId: string;
    r2SecretAccessKey: string;
}): S3Client;
declare function getR2Credentials(region?: string): Promise<R2Secret | undefined>;
declare function getCognitoIdentityCredentials(): Promise<Credentials>;
export declare const S3Utils: {
    deleteFromBucket: typeof deleteFromBucket;
    downloadFromBucket: typeof downloadFromBucket;
    getBucketObjects: typeof getBucketObjects;
    getCognitoIdentityCredentials: typeof getCognitoIdentityCredentials;
    getDownloadUrl: typeof getDownloadUrl;
    getObjectMetadata: typeof getObjectMetadata;
    getPresignedUploadUrl: typeof getPresignedUploadUrl;
    getR2Credentials: typeof getR2Credentials;
    getR2S3Client: typeof getR2S3Client;
    getS3Client: typeof getS3Client;
    uploadToBucket: typeof uploadToBucket;
};
export {};
//# sourceMappingURL=s3.d.ts.map