"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TarUtils = void 0;
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const tar_1 = __importDefault(require("tar"));
async function zipDir(source, dest, excludes = []) {
    const sourceDir = path_1.default.dirname(source);
    const sourceFile = path_1.default.basename(source);
    const patterns = excludes.map((e) => new RegExp(e));
    await tar_1.default.create({
        gzip: true,
        file: dest,
        C: sourceDir,
        filter: function (path) {
            if (patterns.find((p) => p.test(path))) {
                return false;
            }
            else {
                return true;
            }
        },
    }, [sourceFile]);
}
function unzipTar(source, dest) {
    return new Promise((resolve, reject) => {
        const process = (0, child_process_1.spawn)('tar', ['-xvzf', source, '-C', dest]);
        process.on('exit', (code) => resolve(code));
        process.on('error', (error) => reject(error));
    });
}
exports.TarUtils = { zipDir, unzipTar };
//# sourceMappingURL=tar.js.map